@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010 by Daniel Nicoletti                                *
+ *   Copyright (C) 2010-2018 by Daniel Nicoletti                           *
  *   dantti12@gmail.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -29,7 +29,6 @@
 #include <QStandardItemModel>
 #include <QLineEdit>
 #include <QItemSelection>
-#include <QStringBuilder>
 
 #include <QDBusConnection>
 #include <QDBusReply>
@@ -57,10 +56,7 @@ const QDBusArgument &operator>>(const QDBusArgument &argument, DriverMatch &driv
 
 SelectMakeModel::SelectMakeModel(QWidget *parent) :
     QWidget(parent),
-    ui(new Ui::SelectMakeModel),
-    m_ppdRequest(0),
-    m_gotBestDrivers(false),
-    m_hasRecommended(false)
+    ui(new Ui::SelectMakeModel)
 {
     ui->setupUi(this);
 
@@ -73,20 +69,19 @@ SelectMakeModel::SelectMakeModel(QWidget *parent) :
     ui->makeView->setModel(m_sourceModel);
     ui->makeView->setItemDelegate(new NoSelectionRectDelegate(this));
     // Updates the PPD view to the selected Make
-    connect(ui->makeView->selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)),
-            ui->ppdsLV, SLOT(setRootIndex(QModelIndex)));
+    connect(ui->makeView->selectionModel(), &QItemSelectionModel::currentChanged, ui->ppdsLV, &QListView::setRootIndex);
 
     ui->ppdsLV->setModel(m_sourceModel);
     ui->ppdsLV->setItemDelegate(new NoSelectionRectDelegate(this));
     connect(m_sourceModel, &PPDModel::dataChanged, this, &SelectMakeModel::checkChanged);
 
     // Clear the PPD view selection, so the Next/Finish button gets disabled
-    connect(ui->makeView->selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)),
-            ui->ppdsLV->selectionModel(), SLOT(clearSelection()));
+    connect(ui->makeView->selectionModel(), &QItemSelectionModel::currentChanged,
+            ui->ppdsLV->selectionModel(), &QItemSelectionModel::clearSelection);
 
     // Make sure we update the Next/Finish button if a PPD is selected
-    connect(ui->ppdsLV->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-            this, SLOT(checkChanged()));
+    connect(ui->ppdsLV->selectionModel(), &QItemSelectionModel::selectionChanged,
+            this, &SelectMakeModel::checkChanged);
 
     // When the radio button changes the signal must be emitted
     connect(ui->ppdFileRB, &QRadioButton::toggled, this, &SelectMakeModel::checkChanged);
@@ -150,24 +145,24 @@ void SelectMakeModel::setMakeModel(const QString &make, const QString &makeAndMo
     }
 }
 
-void SelectMakeModel::ppdsLoaded()
+void SelectMakeModel::ppdsLoaded(KCupsRequest *request)
 {
-    if (m_ppdRequest->hasError()) {
-        qCWarning(LIBKCUPS) << "Failed to get PPDs" << m_ppdRequest->errorMsg();
-        ui->messageWidget->setText(i18n("Failed to get a list of drivers: '%1'", m_ppdRequest->errorMsg()));
+    if (request->hasError()) {
+        qCWarning(LIBKCUPS) << "Failed to get PPDs" << request->errorMsg();
+        ui->messageWidget->setText(i18n("Failed to get a list of drivers: '%1'", request->errorMsg()));
         ui->messageWidget->animatedShow();
 
         // Force the changed signal to be sent
         checkChanged();
 
-        m_ppdRequest = 0;
     } else {
-        m_ppds = m_ppdRequest->ppds();
+        m_ppds = request->ppds();
 
         // Try to show the PPDs
         setModelData();
     }
-    sender()->deleteLater();
+    m_ppdRequest = nullptr;
+    request->deleteLater();
 }
 
 void SelectMakeModel::checkChanged()
@@ -225,9 +220,10 @@ void SelectMakeModel::getBestDriversFinished(const QDBusMessage &message)
 {
     if (message.type() == QDBusMessage::ReplyMessage && message.arguments().size() == 1) {
         QDBusArgument argument = message.arguments().first().value<QDBusArgument>();
-        m_driverMatchList = qdbus_cast<DriverMatchList>(argument);
+        const DriverMatchList driverMatchList = qdbus_cast<DriverMatchList>(argument);
+        m_driverMatchList = driverMatchList;
         m_hasRecommended = !m_driverMatchList.isEmpty();
-        foreach (const DriverMatch &driverMatch, m_driverMatchList) {
+        for (const DriverMatch &driverMatch : driverMatchList) {
             qCDebug(LIBKCUPS) << driverMatch.ppd << driverMatch.match;
         }
     } else {
@@ -278,8 +274,8 @@ void SelectMakeModel::selectFirstMake()
 
 void SelectMakeModel::selectMakeModelPPD()
 {
-    QList<QStandardItem*> makes = m_sourceModel->findItems(m_make);
-    foreach (QStandardItem *make, makes) {
+    const QList<QStandardItem*> makes = m_sourceModel->findItems(m_make);
+    for (QStandardItem *make : makes) {
         // Check if the item is in this make
         for (int i = 0; i < make->rowCount(); i++) {
             if (make->child(i)->data(PPDModel::PPDMakeAndModel).toString() == m_makeAndModel) {
@@ -314,3 +310,5 @@ void SelectMakeModel::selectRecommendedPPD()
         }
     }
 }
+
+#include "moc_SelectMakeModel.cpp"
